<?php

declare(strict_types=1);

namespace SFL\Fonts;

if ( ! defined( 'ABSPATH' ) ) exit;



if (!class_exists('\SFL\Fonts\SFLFonts')) {

	/**
	* 
	*/
	class SFLFonts {
		
		/**
		 * @var Singleton
		 * @access private
		 * @static
		 */
		private static $_instance = null;
		
		/**
		 * @var Listes des fonts
		 * @access protected
		 * @static
		 */
		protected static $fonts = [];
		
		/**
		 * @var Listes des fonts actifs
		 * @access protected
		 * @static
		 */
		protected static $activated = [];

		/**
		* Méthode qui crée l'unique instance de la classe
		* si elle n'existe pas encore puis la retourne.
		*
		* @param void
		* @return Singleton
		*/
		public static function getInstance() {
			if(is_null(self::$_instance)) self::$_instance = new SFLFonts();
			return self::$_instance;
		}
		
		/**
		* Constructeur de la classe
		*
		* @param void
		* @return void
		*/
		private function __construct() {
			self::$activated = get_option('simple-fonts-loader-activated', array());
			$this->addHooks();
		}

		public function addHooks() {
		}

		public static function getFonts() {
			return self::$fonts;
		}

		public static function getFontsActivated() {
			return self::$activated;
		}

		public static function registerFontFamily(string $slug, string $label = '', $category = 'sans-serif') {
			$fonts = self::$fonts;
			if (!isset($fonts[$slug])) {
				$fonts[$slug] = array('label' => ((!empty($label)) ? $label : $slug), 'category' => ((in_array($category, array('serif', 'sans-serif', 'monospace', 'cursive', 'fantasy', 'system-ui', 'emoji', 'math', 'fangsong'))) ? $category : 'sans-serif'), 'fonts' => array());
				self::$fonts = $fonts;
			}
		}

		public static function registerFont(string $family, string $url, int $weight = 400, string $variant = 'normal') {
			self::registerFontFamily($family);
			$fonts = self::$fonts;
			$variant = (in_array($variant, array('normal', 'italic'))) ? $variant : 'normal' ;
			$fonts[$family]['fonts'][$weight.$variant] = array('weight' => $weight, 'variant' => $variant, 'url' => $url);
			self::$fonts = $fonts;
		}

		public static function activateFont($font) {
			$activated = self::$activated;
			$activated[$font] = true;
			self::$activated = $activated;
			self::saveActivatedFont();
		}

		public static function deactivateFont($font) {
			$activated = self::$activated;
			if (isset($activated[$font])) unset($activated[$font]);
			self::$activated = $activated;
			self::saveActivatedFont();
		}

		private static function saveActivatedFont() {
			$activated = self::$activated;
			update_option('simple-fonts-loader-activated', $activated, true);
		}
	}

	SFLFonts::getInstance();
}