<?php

declare(strict_types=1);

namespace SFL\Front;

if ( ! defined( 'ABSPATH' ) ) exit;



if (!class_exists('\SFL\Front\SFLFront')) {

	/**
	* 
	*/
	class SFLFront {
		
		/**
		 * @var Singleton
		 * @access private
		 * @static
		 */
		private static $_instance = null;

		/**
		* Méthode qui crée l'unique instance de la classe
		* si elle n'existe pas encore puis la retourne.
		*
		* @param void
		* @return Singleton
		*/
		public static function getInstance() {
			if(is_null(self::$_instance)) self::$_instance = new SFLFront();
			return self::$_instance;
		}
		
		/**
		* Constructeur de la classe
		*
		* @param void
		* @return void
		*/
		private function __construct() {
			$this->addHooks();
		}

		public function addHooks() {
			add_action('wp_head', array($this, 'addFontFace'), 1);
		}

		/**
		* Méthode qui ajoute les font-face au style
		*
		* @param void
		* @return void
		*/
		public function addFontFace() {
			$fonts = \SFL\Fonts\SFLFonts::getFonts();
			$activated = \SFL\Fonts\SFLFonts::getFontsActivated();

			echo '<style type="text/css">';

			foreach ($fonts as $slug => $fonts) {
				foreach ($fonts['fonts'] as $font_key => $font) {
					if (in_array($slug.':'.$font_key, array_keys($activated))) {
						echo '@font-face {
							font-family: "'.((isset($fonts['label'])) ? esc_html($fonts['label']) : esc_html(esc_attr($slug))).'";
							font-style: '.esc_attr($font['variant']).';
							font-weight: '.esc_attr($font['weight']).';
							font-display: swap;
							src: url("'.esc_url($font['url']).'") format("woff2");
						}';
					}
				}
			}

			echo '</style>';
		}
	}

	SFLFront::getInstance();
}